import re, logging
logger = logging.getLogger('qondor')

RELEASES = {
    'slc5_amd64_gcc434' : [
        'CMSSW_3_11_3',
        'CMSSW_3_7_0',
        'CMSSW_3_8_0',
        'CMSSW_3_8_6',
        'CMSSW_3_9_2',
        'CMSSW_4_1_1',
        'CMSSW_4_1_10',
        'CMSSW_4_1_2',
        'CMSSW_4_1_3',
        'CMSSW_4_1_4',
        'CMSSW_4_1_5',
        'CMSSW_4_1_6',
        'CMSSW_4_1_7',
        'CMSSW_4_1_8',
        'CMSSW_4_1_9',
        'CMSSW_4_2_0_pre3',
        'CMSSW_4_2_0_pre5',
        'CMSSW_4_2_0_pre7',
        'CMSSW_4_2_0_pre8',
        'CMSSW_4_2_1',
        'CMSSW_4_2_10',
        'CMSSW_4_2_2',
        'CMSSW_4_2_3',
        'CMSSW_4_2_3_SLHC2',
        'CMSSW_4_2_3_SLHC3',
        'CMSSW_4_2_3_SLHC4',
        'CMSSW_4_2_4',
        'CMSSW_4_2_4_g93p01',
        'CMSSW_4_2_4_g94p02',
        'CMSSW_4_2_4_g94p03c',
        'CMSSW_4_2_5',
        'CMSSW_4_2_6',
        'CMSSW_4_2_7',
        'CMSSW_4_2_8',
        'CMSSW_4_2_8_p7rootfix',
        'CMSSW_4_2_8_SLHC1',
        'CMSSW_4_2_8_SLHC2',
        'CMSSW_4_2_8_SLHChcal',
        'CMSSW_4_2_8_SLHChcal2',
        'CMSSW_4_2_8_SLHChcal3',
        'CMSSW_4_2_8_SLHChcal4',
        'CMSSW_4_2_8_SLHChcal5',
        'CMSSW_4_2_8_SLHChcal6',
        'CMSSW_4_2_8_SLHCstd',
        'CMSSW_4_2_8_SLHCstd2',
        'CMSSW_4_2_8_SLHCtk',
        'CMSSW_4_2_8_SLHCtk2',
        'CMSSW_4_2_8_SLHCtk3',
        'CMSSW_4_2_9_HLT',
        'CMSSW_4_2_9_HLT1',
        'CMSSW_4_2_9_HLT2',
        'CMSSW_4_2_9_HLT3',
        'CMSSW_4_3_0',
        'CMSSW_4_3_0_pre1',
        'CMSSW_4_3_0_pre2',
        'CMSSW_4_3_0_pre3',
        'CMSSW_4_3_0_pre4',
        'CMSSW_4_3_0_pre5',
        'CMSSW_4_3_0_pre6',
        'CMSSW_4_3_0_pre6_dqmIO',
        'CMSSW_4_3_0_pre6_r528',
        'CMSSW_4_4_0',
        'CMSSW_4_4_0_pre1',
        'CMSSW_4_4_0_pre10',
        'CMSSW_4_4_0_pre2',
        'CMSSW_4_4_0_pre3',
        'CMSSW_4_4_0_pre4',
        'CMSSW_4_4_0_pre5',
        'CMSSW_4_4_0_pre6',
        'CMSSW_4_4_0_pre7',
        'CMSSW_4_4_0_pre7_g494p02',
        'CMSSW_4_4_0_pre8',
        'CMSSW_4_4_0_pre9',
        'CMSSW_4_4_1',
        'CMSSW_4_4_2',
        'CMSSW_4_4_3',
        'CMSSW_4_4_4',
        'CMSSW_4_4_5',
        'CMSSW_4_4_6',
        'CMSSW_4_4_7',
        'CMSSW_5_0_0',
        'CMSSW_5_0_0_pre1',
        'CMSSW_5_0_0_pre2',
        'CMSSW_5_0_0_pre3',
        'CMSSW_5_0_0_pre4',
        'CMSSW_5_0_0_pre5',
        'CMSSW_5_0_0_pre6',
        'CMSSW_5_0_0_pre6g494',
        'CMSSW_5_0_0_pre7',
        'CMSSW_5_0_0_pre7pythia424',
        'CMSSW_5_0_1',
        ],
    'slc5_amd64_gcc461' : [
        'CMSSW_5_0_0',
        'CMSSW_5_0_1',
        'CMSSW_5_1_0_pre1',
        'CMSSW_5_1_0_pre2',
        'CMSSW_5_2_0_pre1',
        'CMSSW_5_2_0_pre2',
        'CMSSW_5_2_0_pre3',
        'CMSSW_5_2_0_pre4',
        'CMSSW_5_2_0_pre5',
        ],
    'slc5_amd64_gcc462' : [
        'CMSSW_5_1_1',
        'CMSSW_5_1_2',
        'CMSSW_5_1_3',
        'CMSSW_5_2_0',
        'CMSSW_5_2_0_pre5',
        'CMSSW_5_2_0_pre5_TS117504',
        'CMSSW_5_2_0_pre6',
        'CMSSW_5_2_0_pre6DQM',
        'CMSSW_5_2_0_pre6_TS117498',
        'CMSSW_5_2_1',
        'CMSSW_5_2_2',
        'CMSSW_5_2_3',
        'CMSSW_5_2_4',
        'CMSSW_5_2_5',
        'CMSSW_5_2_5_cand1',
        'CMSSW_5_2_6',
        'CMSSW_5_2_7',
        'CMSSW_5_2_7_cand1',
        'CMSSW_5_2_7_cand3',
        'CMSSW_5_2_7_cand4',
        'CMSSW_5_2_8',
        'CMSSW_5_2_9',
        'CMSSW_5_3_0',
        'CMSSW_5_3_1',
        'CMSSW_5_3_10',
        'CMSSW_5_3_11',
        'CMSSW_5_3_11_sherpa2beta2',
        'CMSSW_5_3_12',
        'CMSSW_5_3_12_sherpa2beta2',
        'CMSSW_5_3_13',
        'CMSSW_5_3_13_cand1',
        'CMSSW_5_3_14',
        'CMSSW_5_3_14_LHAPDF590',
        'CMSSW_5_3_14_tauolapp',
        'CMSSW_5_3_15',
        'CMSSW_5_3_16',
        'CMSSW_5_3_17',
        'CMSSW_5_3_18',
        'CMSSW_5_3_19',
        'CMSSW_5_3_1_TS120913',
        'CMSSW_5_3_1_TS121128',
        'CMSSW_5_3_2',
        'CMSSW_5_3_20',
        'CMSSW_5_3_21',
        'CMSSW_5_3_22',
        'CMSSW_5_3_3',
        'CMSSW_5_3_3_cand1',
        'CMSSW_5_3_4',
        'CMSSW_5_3_4_cand1',
        'CMSSW_5_3_4_cand2',
        'CMSSW_5_3_5',
        'CMSSW_5_3_6',
        'CMSSW_5_3_7',
        'CMSSW_5_3_8',
        'CMSSW_5_3_8_HI',
        'CMSSW_5_3_9',
        'CMSSW_5_3_9_sherpa2beta2',
        'CMSSW_6_0_0',
        'CMSSW_6_0_0_pre1',
        'CMSSW_6_0_0_pre10',
        'CMSSW_6_0_0_pre11',
        'CMSSW_6_0_0_pre1_LOOPER',
        'CMSSW_6_0_0_pre2',
        'CMSSW_6_0_0_pre3',
        'CMSSW_6_0_0_pre4',
        'CMSSW_6_0_0_pre5',
        'CMSSW_6_0_0_pre6',
        'CMSSW_6_0_0_pre6g495p01',
        'CMSSW_6_0_0_pre6Nmix',
        'CMSSW_6_0_0_pre7',
        'CMSSW_6_0_0_pre7py273',
        'CMSSW_6_0_0_pre8',
        'CMSSW_6_0_0_pre9',
        'CMSSW_6_0_0_SLHCtkpre1',
        'CMSSW_6_0_0_TS123032',
        'CMSSW_6_0_0_TS123272',
        'CMSSW_6_0_1',
        'CMSSW_6_0_1_PostLS1v1',
        'CMSSW_6_0_1_PostLS1v2',
        'CMSSW_6_1_0_pre1',
        'CMSSW_6_1_0_pre2',
        'CMSSW_6_1_0_pre3',
        'CMSSW_6_1_0_pre3_TS124729',
        'CMSSW_6_1_0_pre4',
        ],
    'slc5_amd64_gcc470' : [
        'CMSSW_6_0_0',
        'CMSSW_6_0_0_pre11',
        'CMSSW_6_0_0_pre3',
        'CMSSW_6_0_0_pre4',
        'CMSSW_6_0_0_pre6',
        'CMSSW_6_0_0_pre6g495p01',
        'CMSSW_6_0_0_pre6Nmix',
        'CMSSW_6_0_0_pre8',
        'CMSSW_6_1_0_pre1',
        'CMSSW_6_1_0_pre2',
        'CMSSW_6_1_0_pre3',
        ],
    'slc5_amd64_gcc472' : [
        'CMSSW_6_0_0',
        'CMSSW_6_0_1',
        'CMSSW_6_0_1_PostLS1v1',
        'CMSSW_6_1_0',
        'CMSSW_6_1_0_pre4',
        'CMSSW_6_1_0_pre5',
        'CMSSW_6_1_0_pre6',
        'CMSSW_6_1_0_pre6g496cand01',
        'CMSSW_6_1_0_pre6_TS126203_TS126341',
        'CMSSW_6_1_0_pre7',
        'CMSSW_6_1_0_pre7_TS127013',
        'CMSSW_6_1_0_pre8',
        'CMSSW_6_1_1',
        'CMSSW_6_1_1_SLHCphase1tk1',
        'CMSSW_6_1_1_SLHCphase2tk1',
        'CMSSW_6_1_2',
        'CMSSW_6_1_2_SLHC1',
        'CMSSW_6_1_2_SLHC2',
        'CMSSW_6_1_2_SLHC3',
        'CMSSW_6_1_2_SLHC4',
        'CMSSW_6_1_2_SLHC5',
        'CMSSW_6_1_2_SLHC6',
        'CMSSW_6_1_2_SLHC7',
        'CMSSW_6_1_2_SLHC8',
        'CMSSW_6_2_0',
        'CMSSW_6_2_0_pre1',
        'CMSSW_6_2_0_pre2',
        'CMSSW_6_2_0_pre3',
        'CMSSW_6_2_0_pre4',
        'CMSSW_6_2_0_pre5',
        'CMSSW_6_2_0_pre6',
        'CMSSW_6_2_0_pre7',
        'CMSSW_6_2_0_pre7_g496p02',
        'CMSSW_6_2_0_pre7_TS132947',
        'CMSSW_6_2_0_pre7_TS133806',
        'CMSSW_6_2_0_pre8',
        'CMSSW_6_2_0_SLHC1',
        'CMSSW_6_2_0_SLHC10',
        'CMSSW_6_2_0_SLHC11',
        'CMSSW_6_2_0_SLHC12',
        'CMSSW_6_2_0_SLHC13',
        'CMSSW_6_2_0_SLHC14',
        'CMSSW_6_2_0_SLHC15',
        'CMSSW_6_2_0_SLHC16',
        'CMSSW_6_2_0_SLHC17',
        'CMSSW_6_2_0_SLHC19',
        'CMSSW_6_2_0_SLHC2',
        'CMSSW_6_2_0_SLHC20',
        'CMSSW_6_2_0_SLHC3',
        'CMSSW_6_2_0_SLHC4',
        'CMSSW_6_2_0_SLHC5',
        'CMSSW_6_2_0_SLHC6',
        'CMSSW_6_2_0_SLHC7',
        'CMSSW_6_2_0_SLHC8',
        'CMSSW_6_2_0_SLHC9',
        'CMSSW_6_2_1',
        'CMSSW_6_2_10',
        'CMSSW_6_2_11',
        'CMSSW_6_2_2',
        'CMSSW_6_2_3',
        'CMSSW_6_2_4',
        'CMSSW_6_2_5',
        'CMSSW_6_2_5_cand1',
        'CMSSW_6_2_6',
        'CMSSW_6_2_7',
        'CMSSW_6_2_8',
        'CMSSW_6_2_9',
        'CMSSW_7_0_0_pre0',
        'CMSSW_7_0_0_pre1',
        'CMSSW_7_0_0_pre2',
        ],
    'slc5_amd64_gcc480' : [
        'CMSSW_6_2_0_pre2',
        ],
    'slc5_amd64_gcc481' : [
        'CMSSW_7_0_0',
        'CMSSW_7_0_0_pre10',
        'CMSSW_7_0_0_pre11',
        'CMSSW_7_0_0_pre12',
        'CMSSW_7_0_0_pre13',
        'CMSSW_7_0_0_pre3',
        'CMSSW_7_0_0_pre4',
        'CMSSW_7_0_0_pre5',
        'CMSSW_7_0_0_pre6',
        'CMSSW_7_0_0_pre7',
        'CMSSW_7_0_0_pre7_THREADED',
        'CMSSW_7_0_0_pre8',
        'CMSSW_7_0_0_pre8_jemalloc341',
        'CMSSW_7_0_0_pre9',
        'CMSSW_7_0_1',
        'CMSSW_7_0_3',
        'CMSSW_7_0_4',
        'CMSSW_7_0_5',
        'CMSSW_7_1_0',
        'CMSSW_7_1_0_pre1',
        'CMSSW_7_1_0_pre2',
        'CMSSW_7_1_0_pre3',
        'CMSSW_7_1_0_pre4',
        'CMSSW_7_1_0_pre5',
        'CMSSW_7_1_0_pre7',
        'CMSSW_7_1_0_pre8',
        'CMSSW_7_1_1',
        'CMSSW_7_2_0_pre6',
        'CMSSW_7_3_0_pre1',
        ],
    'slc5_ia32_gcc434' : [
        'CMSSW_3_10_0',
        'CMSSW_3_10_1',
        'CMSSW_3_11_0',
        'CMSSW_3_11_0_pre4',
        'CMSSW_3_11_0_pre5',
        'CMSSW_3_11_0_pre5r52706b',
        'CMSSW_3_11_1',
        'CMSSW_3_11_2',
        'CMSSW_3_11_3',
        'CMSSW_3_7_0',
        'CMSSW_3_8_0',
        'CMSSW_3_8_1',
        'CMSSW_3_8_2',
        'CMSSW_3_8_3',
        'CMSSW_3_8_4',
        'CMSSW_3_8_5',
        'CMSSW_3_8_6',
        'CMSSW_3_8_7',
        'CMSSW_3_9_0_pre3',
        'CMSSW_3_9_1',
        'CMSSW_3_9_2',
        'CMSSW_3_9_3',
        'CMSSW_3_9_4',
        'CMSSW_3_9_5',
        'CMSSW_3_9_6',
        'CMSSW_3_9_7',
        'CMSSW_3_9_8',
        'CMSSW_3_9_9',
        ],
    'slc6_amd64_gcc462' : [
        'CMSSW_6_0_0',
        'CMSSW_6_0_0_pre1',
        'CMSSW_6_0_0_pre11',
        'CMSSW_6_0_0_pre2',
        'CMSSW_6_0_0_pre3',
        'CMSSW_6_0_0_pre4',
        'CMSSW_6_0_0_pre5',
        'CMSSW_6_0_0_pre6',
        'CMSSW_6_0_0_pre7',
        'CMSSW_6_0_0_pre8',
        'CMSSW_6_0_0_pre9',
        'CMSSW_6_0_1',
        'CMSSW_6_1_0_pre1',
        'CMSSW_6_1_0_pre2',
        'CMSSW_6_1_0_pre3',
        'CMSSW_6_1_0_pre4',
        ],
    'slc6_amd64_gcc472' : [
        'CMSSW_5_3_11',
        'CMSSW_5_3_12',
        'CMSSW_5_3_13',
        'CMSSW_5_3_14',
        'CMSSW_5_3_15',
        'CMSSW_5_3_16',
        'CMSSW_5_3_17',
        'CMSSW_5_3_18',
        'CMSSW_5_3_19',
        'CMSSW_5_3_20',
        'CMSSW_5_3_21',
        'CMSSW_5_3_22',
        'CMSSW_5_3_23',
        'CMSSW_5_3_24',
        'CMSSW_5_3_25',
        'CMSSW_5_3_26',
        'CMSSW_5_3_27',
        'CMSSW_5_3_28',
        'CMSSW_5_3_29',
        'CMSSW_5_3_30',
        'CMSSW_5_3_31',
        'CMSSW_5_3_32',
        'CMSSW_5_3_33',
        'CMSSW_5_3_34',
        'CMSSW_5_3_35',
        'CMSSW_5_3_36',
        'CMSSW_5_3_37',
        'CMSSW_5_3_38',
        'CMSSW_5_3_39',
        'CMSSW_6_2_0',
        'CMSSW_6_2_0_pre3',
        'CMSSW_6_2_0_pre4',
        'CMSSW_6_2_0_pre5',
        'CMSSW_6_2_0_pre5slc6',
        'CMSSW_6_2_0_pre6',
        'CMSSW_6_2_0_pre7',
        'CMSSW_6_2_0_pre8',
        'CMSSW_6_2_0_SLHC1',
        'CMSSW_6_2_0_SLHC10',
        'CMSSW_6_2_0_SLHC11',
        'CMSSW_6_2_0_SLHC12',
        'CMSSW_6_2_0_SLHC13',
        'CMSSW_6_2_0_SLHC14',
        'CMSSW_6_2_0_SLHC15',
        'CMSSW_6_2_0_SLHC15_fixTk1',
        'CMSSW_6_2_0_SLHC16',
        'CMSSW_6_2_0_SLHC17',
        'CMSSW_6_2_0_SLHC17-cms',
        'CMSSW_6_2_0_SLHC18',
        'CMSSW_6_2_0_SLHC19',
        'CMSSW_6_2_0_SLHC20',
        'CMSSW_6_2_0_SLHC21',
        'CMSSW_6_2_0_SLHC22',
        'CMSSW_6_2_0_SLHC23',
        'CMSSW_6_2_0_SLHC24',
        'CMSSW_6_2_0_SLHC25',
        'CMSSW_6_2_0_SLHC26',
        'CMSSW_6_2_0_SLHC27',
        'CMSSW_6_2_0_SLHC28',
        'CMSSW_6_2_1',
        'CMSSW_6_2_10',
        'CMSSW_6_2_11',
        'CMSSW_6_2_12',
        'CMSSW_6_2_3',
        'CMSSW_6_2_4',
        'CMSSW_6_2_5',
        'CMSSW_6_2_6',
        'CMSSW_6_2_7',
        'CMSSW_6_2_8',
        'CMSSW_6_2_9',
        'CMSSW_7_0_0_pre0',
        'CMSSW_7_0_0_pre1',
        'CMSSW_7_0_0_pre2',
        ],
    'slc6_amd64_gcc480' : [
        'CMSSW_6_2_0',
        'CMSSW_6_2_0_noxdaq',
        'CMSSW_6_2_0_p1_gcc481',
        'CMSSW_6_2_0_pre4',
        'CMSSW_6_2_0_pre5',
        'CMSSW_6_2_0_pre6',
        'CMSSW_6_2_0_pre7',
        'CMSSW_6_2_0_pre8',
        'CMSSW_7_0_0_pre0',
        'CMSSW_7_0_0_pre1',
        'CMSSW_7_0_0_pre2',
        ],
    'slc6_amd64_gcc481' : [
        'CMSSW_7_0_0',
        'CMSSW_7_0_0_pre10',
        'CMSSW_7_0_0_pre11',
        'CMSSW_7_0_0_pre12',
        'CMSSW_7_0_0_pre13',
        'CMSSW_7_0_0_pre3',
        'CMSSW_7_0_0_pre4',
        'CMSSW_7_0_0_pre5',
        'CMSSW_7_0_0_pre6',
        'CMSSW_7_0_0_pre7',
        'CMSSW_7_0_0_pre8',
        'CMSSW_7_0_0_pre9',
        'CMSSW_7_0_0_XROOTD',
        'CMSSW_7_0_0_XROOTD2',
        'CMSSW_7_0_1',
        'CMSSW_7_0_2',
        'CMSSW_7_0_3',
        'CMSSW_7_0_4',
        'CMSSW_7_0_5',
        'CMSSW_7_0_6',
        'CMSSW_7_0_7',
        'CMSSW_7_0_8',
        'CMSSW_7_0_9',
        'CMSSW_7_1_0',
        'CMSSW_7_1_0_pre1',
        'CMSSW_7_1_0_pre2',
        'CMSSW_7_1_0_pre3',
        'CMSSW_7_1_0_pre4',
        'CMSSW_7_1_0_pre4_AK4',
        'CMSSW_7_1_0_pre4_GEANT10',
        'CMSSW_7_1_0_pre5',
        'CMSSW_7_1_0_pre6',
        'CMSSW_7_1_0_pre6_THREADED',
        'CMSSW_7_1_0_pre7',
        'CMSSW_7_1_0_pre8',
        'CMSSW_7_1_0_pre9',
        'CMSSW_7_1_0_THREADED_pre2',
        'CMSSW_7_1_1',
        'CMSSW_7_1_10',
        'CMSSW_7_1_11',
        'CMSSW_7_1_12',
        'CMSSW_7_1_13',
        'CMSSW_7_1_14',
        'CMSSW_7_1_15',
        'CMSSW_7_1_16',
        'CMSSW_7_1_17',
        'CMSSW_7_1_18',
        'CMSSW_7_1_19',
        'CMSSW_7_1_2',
        'CMSSW_7_1_20',
        'CMSSW_7_1_21',
        'CMSSW_7_1_22',
        'CMSSW_7_1_23',
        'CMSSW_7_1_24',
        'CMSSW_7_1_25',
        'CMSSW_7_1_26',
        'CMSSW_7_1_27',
        'CMSSW_7_1_28',
        'CMSSW_7_1_29',
        'CMSSW_7_1_3',
        'CMSSW_7_1_30',
        'CMSSW_7_1_31',
        'CMSSW_7_1_32',
        'CMSSW_7_1_33',
        'CMSSW_7_1_34',
        'CMSSW_7_1_35',
        'CMSSW_7_1_36',
        'CMSSW_7_1_37',
        'CMSSW_7_1_38',
        'CMSSW_7_1_39',
        'CMSSW_7_1_4',
        'CMSSW_7_1_40',
        'CMSSW_7_1_41',
        'CMSSW_7_1_42',
        'CMSSW_7_1_43',
        'CMSSW_7_1_44',
        'CMSSW_7_1_45',
        'CMSSW_7_1_46',
        'CMSSW_7_1_5',
        'CMSSW_7_1_6',
        'CMSSW_7_1_7',
        'CMSSW_7_1_8',
        'CMSSW_7_1_9',
        'CMSSW_7_2_0',
        'CMSSW_7_2_0_pre1',
        'CMSSW_7_2_0_pre2',
        'CMSSW_7_2_0_pre3',
        'CMSSW_7_2_0_pre3_conddb1',
        'CMSSW_7_2_0_pre3_conddb2',
        'CMSSW_7_2_0_pre4',
        'CMSSW_7_2_0_pre5',
        'CMSSW_7_2_0_pre6',
        'CMSSW_7_2_0_pre7',
        'CMSSW_7_2_0_pre8',
        'CMSSW_7_2_1',
        'CMSSW_7_2_2',
        'CMSSW_7_2_3',
        'CMSSW_7_2_4',
        'CMSSW_7_2_5',
        'CMSSW_7_3_0',
        'CMSSW_7_3_0_pre1',
        'CMSSW_7_3_0_pre2',
        'CMSSW_7_3_0_pre2_DEVEL',
        'CMSSW_7_3_0_pre3',
        'CMSSW_7_3_1',
        'CMSSW_7_3_2',
        'CMSSW_7_3_3',
        'CMSSW_7_3_4',
        'CMSSW_7_3_5',
        'CMSSW_7_3_6',
        'CMSSW_7_4_0_pre1',
        'CMSSW_7_4_0_pre2',
        'CMSSW_7_4_0_pre3',
        'CMSSW_7_4_0_pre4',
        'CMSSW_7_4_0_pre5',
        'CMSSW_7_4_0_pre6',
        'CMSSW_7_4_0_pre7',
        'CMSSW_7_4_0_pre8',
        'CMSSW_7_4_0_pre9',
        ],
    'slc6_amd64_gcc490' : [
        'CMSSW_7_1_0',
        'CMSSW_7_1_0_pre5',
        'CMSSW_7_1_0_pre6',
        'CMSSW_7_1_0_pre7',
        'CMSSW_7_1_0_pre8',
        'CMSSW_7_1_0_pre9',
        'CMSSW_7_1_1',
        'CMSSW_7_2_0_pre1',
        'CMSSW_7_2_0_pre3',
        ],
    'slc6_amd64_gcc491' : [
        'CMSSW_7_2_0',
        'CMSSW_7_2_0_pre4',
        'CMSSW_7_2_0_pre6',
        'CMSSW_7_2_1',
        'CMSSW_7_3_0',
        'CMSSW_7_3_0_DEBUG',
        'CMSSW_7_3_0_pre1',
        'CMSSW_7_3_0_pre2',
        'CMSSW_7_3_0_pre3',
        'CMSSW_7_3_1',
        'CMSSW_7_3_2',
        'CMSSW_7_3_3',
        'CMSSW_7_3_4',
        'CMSSW_7_3_5',
        'CMSSW_7_3_6',
        'CMSSW_7_4_0',
        'CMSSW_7_4_0_pre1',
        'CMSSW_7_4_0_pre2',
        'CMSSW_7_4_0_pre2_ROOT6',
        'CMSSW_7_4_0_pre3',
        'CMSSW_7_4_0_pre3_ROOT6',
        'CMSSW_7_4_0_pre4',
        'CMSSW_7_4_0_pre4_ROOT6',
        'CMSSW_7_4_0_pre5',
        'CMSSW_7_4_0_pre5_ROOT6',
        'CMSSW_7_4_0_pre6',
        'CMSSW_7_4_0_pre6_ROOT6',
        'CMSSW_7_4_0_pre7',
        'CMSSW_7_4_0_pre7_ROOT6',
        'CMSSW_7_4_0_pre8',
        'CMSSW_7_4_0_pre8_ROOT6',
        'CMSSW_7_4_0_pre9',
        'CMSSW_7_4_0_pre9_ROOT6',
        'CMSSW_7_4_1',
        'CMSSW_7_4_10',
        'CMSSW_7_4_11',
        'CMSSW_7_4_12',
        'CMSSW_7_4_13',
        'CMSSW_7_4_14',
        'CMSSW_7_4_15',
        'CMSSW_7_4_16',
        'CMSSW_7_4_1_ROOT5',
        'CMSSW_7_4_2',
        'CMSSW_7_4_3',
        'CMSSW_7_4_4',
        'CMSSW_7_4_4_ROOT5',
        'CMSSW_7_4_5',
        'CMSSW_7_4_5_ROOT5',
        'CMSSW_7_4_6',
        'CMSSW_7_4_7',
        'CMSSW_7_4_8',
        'CMSSW_7_4_9',
        'CMSSW_7_5_0',
        'CMSSW_7_5_0_pre1',
        'CMSSW_7_5_0_pre1_ROOT5',
        'CMSSW_7_5_0_pre2',
        'CMSSW_7_5_0_pre3',
        'CMSSW_7_5_0_pre3_ROOT5',
        'CMSSW_7_5_0_pre4',
        'CMSSW_7_5_0_pre4_ROOT5',
        'CMSSW_7_5_0_pre5',
        'CMSSW_7_5_0_pre6',
        'CMSSW_7_5_1',
        'CMSSW_7_5_2',
        'CMSSW_7_5_3',
        'CMSSW_7_5_4',
        'CMSSW_7_5_5',
        'CMSSW_7_5_6',
        'CMSSW_7_5_7',
        'CMSSW_7_5_8',
        'CMSSW_7_5_9',
        'CMSSW_7_6_0_pre1',
        'CMSSW_7_6_0_pre2',
        ],
    'slc6_amd64_gcc493' : [
        'CMSSW_7_6_0',
        'CMSSW_7_6_0_pre2',
        'CMSSW_7_6_0_pre3',
        'CMSSW_7_6_0_pre4',
        'CMSSW_7_6_0_pre5',
        'CMSSW_7_6_0_pre6',
        'CMSSW_7_6_0_pre7',
        'CMSSW_7_6_1',
        'CMSSW_7_6_2',
        'CMSSW_7_6_3',
        'CMSSW_7_6_4',
        'CMSSW_7_6_5',
        'CMSSW_7_6_6',
        'CMSSW_7_6_7',
        'CMSSW_8_0_0',
        'CMSSW_8_0_0_pre1',
        'CMSSW_8_0_0_pre2',
        'CMSSW_8_0_0_pre3',
        'CMSSW_8_0_0_pre4',
        'CMSSW_8_0_0_pre5',
        'CMSSW_8_0_0_pre6',
        'CMSSW_8_0_1',
        'CMSSW_8_0_10',
        'CMSSW_8_0_11',
        'CMSSW_8_0_12',
        'CMSSW_8_0_13',
        'CMSSW_8_0_14',
        'CMSSW_8_0_15',
        'CMSSW_8_0_16',
        'CMSSW_8_0_17',
        'CMSSW_8_0_18',
        'CMSSW_8_0_19',
        'CMSSW_8_0_2',
        'CMSSW_8_0_20',
        'CMSSW_8_0_22',
        'CMSSW_8_0_23',
        'CMSSW_8_0_24',
        'CMSSW_8_0_3',
        'CMSSW_8_0_4',
        'CMSSW_8_0_5',
        'CMSSW_8_0_6',
        'CMSSW_8_0_7',
        'CMSSW_8_0_8',
        'CMSSW_8_0_9',
        'CMSSW_8_1_0_pre1',
        'CMSSW_8_1_0_pre10',
        'CMSSW_8_1_0_pre2',
        'CMSSW_8_1_0_pre3',
        'CMSSW_8_1_0_pre4',
        'CMSSW_8_1_0_pre5',
        'CMSSW_8_1_0_pre6',
        'CMSSW_8_1_0_pre7',
        'CMSSW_8_1_0_pre8',
        'CMSSW_8_1_0_pre9',
        'CMSSW_8_1_0_pre9_Geant4102',
        ],
    'slc6_amd64_gcc530' : [
        'CMSSW_8_0_0',
        'CMSSW_8_0_0_pre5',
        'CMSSW_8_0_0_pre6',
        'CMSSW_8_0_1',
        'CMSSW_8_0_10',
        'CMSSW_8_0_11',
        'CMSSW_8_0_12',
        'CMSSW_8_0_13',
        'CMSSW_8_0_14',
        'CMSSW_8_0_15',
        'CMSSW_8_0_16',
        'CMSSW_8_0_17',
        'CMSSW_8_0_18',
        'CMSSW_8_0_18_Geant4102',
        'CMSSW_8_0_19',
        'CMSSW_8_0_19_Geant4102',
        'CMSSW_8_0_2',
        'CMSSW_8_0_20',
        'CMSSW_8_0_21',
        'CMSSW_8_0_22',
        'CMSSW_8_0_23',
        'CMSSW_8_0_24',
        'CMSSW_8_0_25',
        'CMSSW_8_0_26',
        'CMSSW_8_0_27',
        'CMSSW_8_0_28',
        'CMSSW_8_0_29',
        'CMSSW_8_0_3',
        'CMSSW_8_0_30',
        'CMSSW_8_0_31',
        'CMSSW_8_0_32',
        'CMSSW_8_0_33',
        'CMSSW_8_0_34',
        'CMSSW_8_0_35',
        'CMSSW_8_0_4',
        'CMSSW_8_0_5',
        'CMSSW_8_0_6',
        'CMSSW_8_0_7',
        'CMSSW_8_0_8',
        'CMSSW_8_0_9',
        'CMSSW_8_1_0',
        'CMSSW_8_1_0_pre1',
        'CMSSW_8_1_0_pre10',
        'CMSSW_8_1_0_pre11',
        'CMSSW_8_1_0_pre12',
        'CMSSW_8_1_0_pre13',
        'CMSSW_8_1_0_pre14',
        'CMSSW_8_1_0_pre15',
        'CMSSW_8_1_0_pre16',
        'CMSSW_8_1_0_pre2',
        'CMSSW_8_1_0_pre3',
        'CMSSW_8_1_0_pre4',
        'CMSSW_8_1_0_pre5',
        'CMSSW_8_1_0_pre6',
        'CMSSW_8_1_0_pre7',
        'CMSSW_8_1_0_pre8',
        'CMSSW_8_1_0_pre9',
        'CMSSW_8_1_0_pre9_Geant4102',
        'CMSSW_8_2_0',
        'CMSSW_8_3_0',
        'CMSSW_8_4_0',
        'CMSSW_9_0_0',
        'CMSSW_9_0_0_pre1',
        'CMSSW_9_0_0_pre2',
        'CMSSW_9_0_0_pre2_ROOT6',
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre4',
        'CMSSW_9_0_0_pre5',
        'CMSSW_9_0_0_pre6',
        'CMSSW_9_0_1',
        'CMSSW_9_0_2',
        'CMSSW_9_0_3',
        'CMSSW_9_0_4',
        'CMSSW_9_1_0',
        'CMSSW_9_1_0_pre1',
        'CMSSW_9_1_0_pre2',
        'CMSSW_9_1_0_pre3',
        'CMSSW_9_1_1',
        'CMSSW_9_1_2',
        'CMSSW_9_2_0',
        'CMSSW_9_2_1',
        'CMSSW_9_2_10',
        'CMSSW_9_2_11',
        'CMSSW_9_2_12',
        'CMSSW_9_2_13',
        'CMSSW_9_2_14',
        'CMSSW_9_2_15',
        'CMSSW_9_2_2',
        'CMSSW_9_2_3',
        'CMSSW_9_2_4',
        'CMSSW_9_2_5',
        'CMSSW_9_2_6',
        'CMSSW_9_2_7',
        'CMSSW_9_2_8',
        'CMSSW_9_2_9',
        'CMSSW_9_3_0_pre1',
        ],
    'slc6_amd64_gcc600' : [
        'CMSSW_8_1_0',
        'CMSSW_8_1_0_pre10',
        'CMSSW_8_1_0_pre11',
        'CMSSW_8_1_0_pre12',
        'CMSSW_8_1_0_pre13',
        'CMSSW_8_1_0_pre14',
        'CMSSW_8_1_0_pre15',
        'CMSSW_8_1_0_pre16',
        'CMSSW_8_1_0_pre9',
        'CMSSW_9_0_0_pre1',
        ],
    'slc6_amd64_gcc620' : [
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre4',
        'CMSSW_9_0_0_pre5',
        ],
    'slc6_amd64_gcc630' : [
        'CMSSW_10_0_0',
        'CMSSW_10_0_0_MWGR1',
        'CMSSW_10_0_0_pre1',
        'CMSSW_10_0_0_pre2',
        'CMSSW_10_0_0_pre3',
        'CMSSW_10_0_0_pre3_G4VecGeom',
        'CMSSW_10_0_0_pre3_G4VecGeom1',
        'CMSSW_10_0_0_pre3_G4VecGeom2',
        'CMSSW_10_0_0_pre3_GEANT4',
        'CMSSW_10_0_1',
        'CMSSW_10_0_2',
        'CMSSW_10_0_3',
        'CMSSW_10_0_4',
        'CMSSW_10_0_5',
        'CMSSW_10_1_0',
        'CMSSW_10_1_0_pre1',
        'CMSSW_10_1_0_pre2',
        'CMSSW_10_1_0_pre3',
        'CMSSW_10_1_1',
        'CMSSW_10_1_10',
        'CMSSW_10_1_11',
        'CMSSW_10_1_2',
        'CMSSW_10_1_3',
        'CMSSW_10_1_4',
        'CMSSW_10_1_5',
        'CMSSW_10_1_6',
        'CMSSW_10_1_7',
        'CMSSW_10_1_8',
        'CMSSW_10_1_9',
        'CMSSW_10_2_0',
        'CMSSW_10_2_0_pre1',
        'CMSSW_10_2_0_pre1_ROOT612',
        'CMSSW_10_2_0_pre2',
        'CMSSW_10_2_0_pre3',
        'CMSSW_10_2_0_pre4',
        'CMSSW_10_2_0_pre5',
        'CMSSW_10_2_0_pre6',
        'CMSSW_9_0_0',
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre5',
        'CMSSW_9_0_0_pre6',
        'CMSSW_9_0_1',
        'CMSSW_9_0_2',
        'CMSSW_9_0_3',
        'CMSSW_9_0_4',
        'CMSSW_9_1_0',
        'CMSSW_9_1_0_pre1',
        'CMSSW_9_1_0_pre2',
        'CMSSW_9_1_0_pre3',
        'CMSSW_9_1_1',
        'CMSSW_9_2_0',
        'CMSSW_9_2_10',
        'CMSSW_9_2_11',
        'CMSSW_9_2_12',
        'CMSSW_9_2_13',
        'CMSSW_9_2_14',
        'CMSSW_9_2_15',
        'CMSSW_9_2_2',
        'CMSSW_9_2_3',
        'CMSSW_9_2_4',
        'CMSSW_9_2_5',
        'CMSSW_9_2_6',
        'CMSSW_9_2_7',
        'CMSSW_9_2_8',
        'CMSSW_9_2_9',
        'CMSSW_9_3_0',
        'CMSSW_9_3_0_pre1',
        'CMSSW_9_3_0_pre2',
        'CMSSW_9_3_0_pre3',
        'CMSSW_9_3_0_pre4',
        'CMSSW_9_3_0_pre5',
        'CMSSW_9_3_1',
        'CMSSW_9_3_10',
        'CMSSW_9_3_11',
        'CMSSW_9_3_12',
        'CMSSW_9_3_13',
        'CMSSW_9_3_14',
        'CMSSW_9_3_15',
        'CMSSW_9_3_16',
        'CMSSW_9_3_17',
        'CMSSW_9_3_18',
        'CMSSW_9_3_2',
        'CMSSW_9_3_3',
        'CMSSW_9_3_4',
        'CMSSW_9_3_5',
        'CMSSW_9_3_6',
        'CMSSW_9_3_7',
        'CMSSW_9_3_8',
        'CMSSW_9_3_9',
        'CMSSW_9_4_0',
        'CMSSW_9_4_0_pre1',
        'CMSSW_9_4_0_pre2',
        'CMSSW_9_4_0_pre3',
        'CMSSW_9_4_1',
        'CMSSW_9_4_10',
        'CMSSW_9_4_11',
        'CMSSW_9_4_11_cand1',
        'CMSSW_9_4_11_cand2',
        'CMSSW_9_4_12',
        'CMSSW_9_4_13',
        'CMSSW_9_4_13_UL1',
        'CMSSW_9_4_14',
        'CMSSW_9_4_15',
        'CMSSW_9_4_16',
        'CMSSW_9_4_17',
        'CMSSW_9_4_2',
        'CMSSW_9_4_3',
        'CMSSW_9_4_4',
        'CMSSW_9_4_5',
        'CMSSW_9_4_5_cand1',
        'CMSSW_9_4_6',
        'CMSSW_9_4_7',
        'CMSSW_9_4_8',
        'CMSSW_9_4_9',
        'CMSSW_9_4_9_cand1',
        'CMSSW_9_4_9_cand2',
        ],
    'slc6_amd64_gcc700' : [
        'CMSSW_10_0_0',
        'CMSSW_10_0_0_pre1',
        'CMSSW_10_0_0_pre2',
        'CMSSW_10_0_0_pre3',
        'CMSSW_10_1_0',
        'CMSSW_10_1_0_pre1',
        'CMSSW_10_1_0_pre2',
        'CMSSW_10_1_0_pre3',
        'CMSSW_10_2_0',
        'CMSSW_10_2_0_pre1',
        'CMSSW_10_2_0_pre2',
        'CMSSW_10_2_0_pre3',
        'CMSSW_10_2_0_pre4',
        'CMSSW_10_2_0_pre5',
        'CMSSW_10_2_0_pre6',
        'CMSSW_10_2_1',
        'CMSSW_10_2_10',
        'CMSSW_10_2_11',
        'CMSSW_10_2_12',
        'CMSSW_10_2_13',
        'CMSSW_10_2_14',
        'CMSSW_10_2_15',
        'CMSSW_10_2_16',
        'CMSSW_10_2_17',
        'CMSSW_10_2_18',
        'CMSSW_10_2_19',
        'CMSSW_10_2_2',
        'CMSSW_10_2_20',
        'CMSSW_10_2_21',
        'CMSSW_10_2_22',
        'CMSSW_10_2_3',
        'CMSSW_10_2_4',
        'CMSSW_10_2_5',
        'CMSSW_10_2_6',
        'CMSSW_10_2_7',
        'CMSSW_10_2_8',
        'CMSSW_10_2_9',
        'CMSSW_10_3_0',
        'CMSSW_10_3_0_pre1',
        'CMSSW_10_3_0_pre2',
        'CMSSW_10_3_0_pre3',
        'CMSSW_10_3_0_pre4',
        'CMSSW_10_3_0_pre5',
        'CMSSW_10_3_0_pre6',
        'CMSSW_10_3_1',
        'CMSSW_10_3_2',
        'CMSSW_10_3_3',
        'CMSSW_10_3_4',
        'CMSSW_10_4_0',
        'CMSSW_10_4_0_mtd1',
        'CMSSW_10_4_0_mtd2',
        'CMSSW_10_4_0_mtd3',
        'CMSSW_10_4_0_mtd4',
        'CMSSW_10_4_0_mtd5',
        'CMSSW_10_4_0_pre1',
        'CMSSW_10_4_0_pre2',
        'CMSSW_10_4_0_pre3',
        'CMSSW_10_4_0_pre4',
        'CMSSW_10_5_0',
        'CMSSW_10_5_0_pre1',
        'CMSSW_10_5_0_pre2',
        'CMSSW_9_2_0',
        'CMSSW_9_3_0',
        'CMSSW_9_3_0_pre2',
        'CMSSW_9_3_0_pre3',
        'CMSSW_9_3_0_pre4',
        'CMSSW_9_3_0_pre5',
        'CMSSW_9_3_1',
        'CMSSW_9_3_2',
        'CMSSW_9_3_3',
        'CMSSW_9_4_0_pre1',
        'CMSSW_9_4_0_pre2',
        'CMSSW_9_4_0_pre3',
        ],
    'slc6_mic_gcc481' : [
        'CMSSW_7_0_0_pre7',
        ],
    'slc7_aarch64_gcc530' : [
        'CMSSW_8_0_0',
        'CMSSW_8_0_1',
        'CMSSW_8_0_2',
        'CMSSW_8_1_0',
        'CMSSW_8_1_0_pre1',
        'CMSSW_8_1_0_pre10',
        'CMSSW_8_1_0_pre12',
        'CMSSW_8_1_0_pre13',
        'CMSSW_8_1_0_pre14',
        'CMSSW_8_1_0_pre15',
        'CMSSW_8_1_0_pre16',
        'CMSSW_8_1_0_pre2',
        'CMSSW_8_1_0_pre3',
        'CMSSW_8_1_0_pre4',
        'CMSSW_8_1_0_pre5',
        'CMSSW_8_1_0_pre6',
        'CMSSW_8_1_0_pre7',
        'CMSSW_8_1_0_pre8',
        'CMSSW_8_1_0_pre9',
        'CMSSW_8_2_0',
        'CMSSW_9_0_0_pre2',
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre4',
        'CMSSW_9_2_0',
        'CMSSW_9_2_1',
        'CMSSW_9_2_2',
        'CMSSW_9_2_3',
        'CMSSW_9_2_4',
        'CMSSW_9_3_0_pre1',
        ],
    'slc7_aarch64_gcc700' : [
        'CMSSW_10_0_0',
        'CMSSW_10_0_0_pre1',
        'CMSSW_10_0_0_pre2',
        'CMSSW_10_0_0_pre3',
        'CMSSW_10_1_0',
        'CMSSW_10_1_0_pre3',
        'CMSSW_10_2_0',
        'CMSSW_10_2_0_pre1',
        'CMSSW_10_2_0_pre2',
        'CMSSW_10_2_0_pre3',
        'CMSSW_10_2_0_pre4',
        'CMSSW_10_2_0_pre6',
        'CMSSW_10_3_0_pre1',
        'CMSSW_10_3_0_pre3',
        'CMSSW_10_3_0_pre4',
        'CMSSW_10_3_0_pre5',
        'CMSSW_10_3_0_pre6',
        'CMSSW_10_4_0',
        'CMSSW_10_4_0_pre3',
        'CMSSW_10_4_0_pre4',
        'CMSSW_10_5_0_pre1',
        'CMSSW_10_5_0_pre2',
        'CMSSW_10_6_0',
        'CMSSW_10_6_0_pre1',
        'CMSSW_10_6_0_pre2',
        'CMSSW_10_6_0_pre3',
        'CMSSW_11_0_0_pre1',
        'CMSSW_11_0_0_pre2',
        'CMSSW_11_0_0_pre3',
        'CMSSW_11_0_0_pre4',
        'CMSSW_11_0_0_pre5',
        'CMSSW_11_0_0_pre6',
        'CMSSW_11_0_0_pre7',
        'CMSSW_9_2_0',
        'CMSSW_9_3_0',
        'CMSSW_9_3_0_pre2',
        'CMSSW_9_3_0_pre3',
        'CMSSW_9_3_0_pre4',
        'CMSSW_9_3_0_pre5',
        'CMSSW_9_3_1',
        'CMSSW_9_3_3',
        ],
    'slc7_aarch64_gcc820' : [
        'CMSSW_11_0_0',
        'CMSSW_11_0_0_pre10',
        'CMSSW_11_0_0_pre11',
        'CMSSW_11_0_0_pre12',
        'CMSSW_11_0_0_pre13',
        'CMSSW_11_0_0_pre8',
        'CMSSW_11_0_0_pre9',
        'CMSSW_11_0_1',
        'CMSSW_11_1_0_pre1',
        'CMSSW_11_1_0_pre2',
        'CMSSW_11_1_0_pre2_Patatrack',
        'CMSSW_11_1_0_pre3',
        'CMSSW_11_1_0_pre4',
        'CMSSW_11_1_0_pre4_Patatrack',
        'CMSSW_11_1_0_pre5',
        'CMSSW_11_1_0_pre5_Patatrack',
        'CMSSW_11_1_0_pre6',
        ],
    'slc7_amd64_gcc493' : [
        'CMSSW_7_6_0',
        'CMSSW_7_6_0_pre4',
        'CMSSW_7_6_0_pre5',
        'CMSSW_7_6_0_pre6',
        'CMSSW_7_6_0_pre7',
        'CMSSW_7_6_1',
        'CMSSW_7_6_2',
        'CMSSW_7_6_3',
        'CMSSW_7_6_4',
        'CMSSW_7_6_5',
        'CMSSW_7_6_6',
        'CMSSW_7_6_7',
        'CMSSW_8_0_0_pre1',
        'CMSSW_8_0_0_pre2',
        'CMSSW_8_0_0_pre3',
        'CMSSW_8_0_0_pre4',
        'CMSSW_8_0_0_pre5',
        ],
    'slc7_amd64_gcc530' : [
        'CMSSW_8_0_0',
        'CMSSW_8_0_0_pre6',
        'CMSSW_8_0_1',
        'CMSSW_8_0_10',
        'CMSSW_8_0_11',
        'CMSSW_8_0_12',
        'CMSSW_8_0_13',
        'CMSSW_8_0_14',
        'CMSSW_8_0_15',
        'CMSSW_8_0_16',
        'CMSSW_8_0_17',
        'CMSSW_8_0_18',
        'CMSSW_8_0_19',
        'CMSSW_8_0_2',
        'CMSSW_8_0_20',
        'CMSSW_8_0_21',
        'CMSSW_8_0_22',
        'CMSSW_8_0_23',
        'CMSSW_8_0_24',
        'CMSSW_8_0_26',
        'CMSSW_8_0_27',
        'CMSSW_8_0_28',
        'CMSSW_8_0_29',
        'CMSSW_8_0_3',
        'CMSSW_8_0_30',
        'CMSSW_8_0_31',
        'CMSSW_8_0_32',
        'CMSSW_8_0_33_UL',
        'CMSSW_8_0_34_UL',
        'CMSSW_8_0_35',
        'CMSSW_8_0_4',
        'CMSSW_8_0_5',
        'CMSSW_8_0_6',
        'CMSSW_8_0_7',
        'CMSSW_8_0_8',
        'CMSSW_8_0_9',
        'CMSSW_8_1_0',
        'CMSSW_8_1_0_pre1',
        'CMSSW_8_1_0_pre10',
        'CMSSW_8_1_0_pre11',
        'CMSSW_8_1_0_pre12',
        'CMSSW_8_1_0_pre13',
        'CMSSW_8_1_0_pre14',
        'CMSSW_8_1_0_pre15',
        'CMSSW_8_1_0_pre16',
        'CMSSW_8_1_0_pre2',
        'CMSSW_8_1_0_pre3',
        'CMSSW_8_1_0_pre4',
        'CMSSW_8_1_0_pre5',
        'CMSSW_8_1_0_pre6',
        'CMSSW_8_1_0_pre7',
        'CMSSW_8_1_0_pre8',
        'CMSSW_8_1_0_pre9',
        'CMSSW_8_2_0',
        'CMSSW_8_3_0',
        'CMSSW_8_4_0',
        'CMSSW_9_0_0',
        'CMSSW_9_0_0_pre1',
        'CMSSW_9_0_0_pre2',
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre4',
        'CMSSW_9_0_0_pre5',
        'CMSSW_9_0_0_pre6',
        'CMSSW_9_0_1',
        'CMSSW_9_0_2',
        'CMSSW_9_0_3',
        'CMSSW_9_0_4',
        'CMSSW_9_1_0',
        'CMSSW_9_1_0_pre1',
        'CMSSW_9_1_0_pre2',
        'CMSSW_9_1_0_pre3',
        'CMSSW_9_1_1',
        'CMSSW_9_1_2',
        'CMSSW_9_2_0',
        'CMSSW_9_2_1',
        'CMSSW_9_2_10',
        'CMSSW_9_2_11',
        'CMSSW_9_2_12',
        'CMSSW_9_2_13',
        'CMSSW_9_2_14',
        'CMSSW_9_2_15',
        'CMSSW_9_2_2',
        'CMSSW_9_2_3',
        'CMSSW_9_2_4',
        'CMSSW_9_2_5',
        'CMSSW_9_2_6',
        'CMSSW_9_2_7',
        'CMSSW_9_2_8',
        'CMSSW_9_2_9',
        'CMSSW_9_3_0_pre1',
        ],
    'slc7_amd64_gcc620' : [
        'CMSSW_9_0_0_pre3',
        'CMSSW_9_0_0_pre4',
        'CMSSW_9_0_0_pre5',
        'CMSSW_9_0_0_pre6',
        ],
    'slc7_amd64_gcc630' : [
        'CMSSW_10_0_0',
        'CMSSW_10_0_0_MWGR1',
        'CMSSW_10_0_0_pre1',
        'CMSSW_10_0_0_pre2',
        'CMSSW_10_0_0_pre3',
        'CMSSW_10_0_1',
        'CMSSW_10_0_2',
        'CMSSW_10_0_3',
        'CMSSW_10_0_4',
        'CMSSW_10_0_5',
        'CMSSW_10_1_0',
        'CMSSW_10_1_0_pre1',
        'CMSSW_10_1_0_pre2',
        'CMSSW_10_1_0_pre3',
        'CMSSW_10_1_1',
        'CMSSW_10_1_10',
        'CMSSW_10_1_11',
        'CMSSW_10_1_2',
        'CMSSW_10_1_3',
        'CMSSW_10_1_4',
        'CMSSW_10_1_5',
        'CMSSW_10_1_6',
        'CMSSW_10_1_7',
        'CMSSW_10_1_8',
        'CMSSW_10_1_9',
        'CMSSW_10_2_0',
        'CMSSW_10_2_0_pre1',
        'CMSSW_10_2_0_pre1_ROOT612',
        'CMSSW_10_2_0_pre2',
        'CMSSW_10_2_0_pre3',
        'CMSSW_10_2_0_pre4',
        'CMSSW_10_2_0_pre5',
        'CMSSW_10_2_0_pre6',
        'CMSSW_9_0_0',
        'CMSSW_9_0_0_pre6',
        'CMSSW_9_0_1',
        'CMSSW_9_0_2',
        'CMSSW_9_0_3',
        'CMSSW_9_0_4',
        'CMSSW_9_1_0',
        'CMSSW_9_1_0_pre1',
        'CMSSW_9_1_0_pre2',
        'CMSSW_9_1_0_pre3',
        'CMSSW_9_1_1',
        'CMSSW_9_1_2',
        'CMSSW_9_2_0',
        'CMSSW_9_2_10',
        'CMSSW_9_2_11',
        'CMSSW_9_2_12',
        'CMSSW_9_2_13',
        'CMSSW_9_2_14',
        'CMSSW_9_2_15',
        'CMSSW_9_2_2',
        'CMSSW_9_2_3',
        'CMSSW_9_2_4',
        'CMSSW_9_2_5',
        'CMSSW_9_2_6',
        'CMSSW_9_2_7',
        'CMSSW_9_2_8',
        'CMSSW_9_2_9',
        'CMSSW_9_3_0',
        'CMSSW_9_3_0_pre1',
        'CMSSW_9_3_0_pre2',
        'CMSSW_9_3_0_pre3',
        'CMSSW_9_3_0_pre4',
        'CMSSW_9_3_0_pre5',
        'CMSSW_9_3_1',
        'CMSSW_9_3_10',
        'CMSSW_9_3_11',
        'CMSSW_9_3_12',
        'CMSSW_9_3_13',
        'CMSSW_9_3_14',
        'CMSSW_9_3_15',
        'CMSSW_9_3_16',
        'CMSSW_9_3_17',
        'CMSSW_9_3_18',
        'CMSSW_9_3_2',
        'CMSSW_9_3_3',
        'CMSSW_9_3_4',
        'CMSSW_9_3_5',
        'CMSSW_9_3_6',
        'CMSSW_9_3_7',
        'CMSSW_9_3_8',
        'CMSSW_9_3_9',
        'CMSSW_9_4_0',
        'CMSSW_9_4_0_pre1',
        'CMSSW_9_4_0_pre2',
        'CMSSW_9_4_0_pre3',
        'CMSSW_9_4_1',
        'CMSSW_9_4_10',
        'CMSSW_9_4_11',
        'CMSSW_9_4_11_cand1',
        'CMSSW_9_4_11_cand2',
        'CMSSW_9_4_12',
        'CMSSW_9_4_13',
        'CMSSW_9_4_13_UL1',
        'CMSSW_9_4_14_UL',
        'CMSSW_9_4_15',
        'CMSSW_9_4_16_UL',
        'CMSSW_9_4_17',
        'CMSSW_9_4_2',
        'CMSSW_9_4_3',
        'CMSSW_9_4_4',
        'CMSSW_9_4_5',
        'CMSSW_9_4_6',
        'CMSSW_9_4_7',
        'CMSSW_9_4_8',
        'CMSSW_9_4_9',
        ],
    'slc7_amd64_gcc700' : [
        'CMSSW_10_0_0',
        'CMSSW_10_0_0_pre2',
        'CMSSW_10_0_0_pre3',
        'CMSSW_10_1_0',
        'CMSSW_10_1_0_pre1',
        'CMSSW_10_1_0_pre2',
        'CMSSW_10_1_0_pre3',
        'CMSSW_10_1_10',
        'CMSSW_10_1_11',
        'CMSSW_10_1_5',
        'CMSSW_10_1_6',
        'CMSSW_10_1_7',
        'CMSSW_10_1_8',
        'CMSSW_10_1_9',
        'CMSSW_10_2_0',
        'CMSSW_10_2_0_pre1',
        'CMSSW_10_2_0_pre2',
        'CMSSW_10_2_0_pre3',
        'CMSSW_10_2_0_pre4',
        'CMSSW_10_2_0_pre5',
        'CMSSW_10_2_0_pre6',
        'CMSSW_10_2_1',
        'CMSSW_10_2_10',
        'CMSSW_10_2_11',
        'CMSSW_10_2_12',
        'CMSSW_10_2_13',
        'CMSSW_10_2_14',
        'CMSSW_10_2_15',
        'CMSSW_10_2_16_UL',
        'CMSSW_10_2_17',
        'CMSSW_10_2_18',
        'CMSSW_10_2_19',
        'CMSSW_10_2_2',
        'CMSSW_10_2_20_UL',
        'CMSSW_10_2_21',
        'CMSSW_10_2_22',
        'CMSSW_10_2_3',
        'CMSSW_10_2_4',
        'CMSSW_10_2_5',
        'CMSSW_10_2_6',
        'CMSSW_10_2_7',
        'CMSSW_10_2_8',
        'CMSSW_10_2_9',
        'CMSSW_10_3_0',
        'CMSSW_10_3_0_pre1',
        'CMSSW_10_3_0_pre2',
        'CMSSW_10_3_0_pre3',
        'CMSSW_10_3_0_pre4',
        'CMSSW_10_3_0_pre5',
        'CMSSW_10_3_0_pre6',
        'CMSSW_10_3_1',
        'CMSSW_10_3_2',
        'CMSSW_10_3_3',
        'CMSSW_10_3_4',
        'CMSSW_10_4_0',
        'CMSSW_10_4_0_mtd1',
        'CMSSW_10_4_0_mtd2',
        'CMSSW_10_4_0_mtd3',
        'CMSSW_10_4_0_mtd4',
        'CMSSW_10_4_0_mtd5',
        'CMSSW_10_4_0_pre1',
        'CMSSW_10_4_0_pre2',
        'CMSSW_10_4_0_pre3',
        'CMSSW_10_4_0_pre4',
        'CMSSW_10_5_0',
        'CMSSW_10_5_0_pre1',
        'CMSSW_10_5_0_pre1_ROOT614',
        'CMSSW_10_5_0_pre2',
        'CMSSW_10_5_0_pre2_G4v1043',
        'CMSSW_10_6_0',
        'CMSSW_10_6_0_pre1',
        'CMSSW_10_6_0_pre2',
        'CMSSW_10_6_0_pre3',
        'CMSSW_10_6_0_pre3_ROOT614',
        'CMSSW_10_6_0_pre4',
        'CMSSW_10_6_1',
        'CMSSW_10_6_10',
        'CMSSW_10_6_11',
        'CMSSW_10_6_11_CANDIDATE',
        'CMSSW_10_6_11_CANDIDATE2',
        'CMSSW_10_6_11_CANDIDATE3',
        'CMSSW_10_6_12',
        'CMSSW_10_6_2',
        'CMSSW_10_6_3',
        'CMSSW_10_6_4',
        'CMSSW_10_6_5',
        'CMSSW_10_6_6',
        'CMSSW_10_6_7',
        'CMSSW_10_6_8',
        'CMSSW_10_6_9',
        'CMSSW_11_0_0_pre1',
        'CMSSW_11_0_0_pre2',
        'CMSSW_11_0_0_pre3',
        'CMSSW_11_0_0_pre4',
        'CMSSW_11_0_0_pre5',
        'CMSSW_11_0_0_pre6',
        'CMSSW_11_0_0_pre7',
        ],
    'slc7_amd64_gcc820' : [
        'CMSSW_10_4_0',
        'CMSSW_10_4_0_pre2',
        'CMSSW_10_4_0_pre3',
        'CMSSW_10_4_0_pre4',
        'CMSSW_10_5_0',
        'CMSSW_10_5_0_pre1',
        'CMSSW_10_5_0_pre2',
        'CMSSW_10_6_0',
        'CMSSW_10_6_0_pre1',
        'CMSSW_10_6_0_pre2',
        'CMSSW_10_6_0_pre3',
        'CMSSW_10_6_0_pre4',
        'CMSSW_10_6_1',
        'CMSSW_10_6_10',
        'CMSSW_10_6_11',
        'CMSSW_10_6_11_CANDIDATE',
        'CMSSW_10_6_11_CANDIDATE2',
        'CMSSW_10_6_11_CANDIDATE3',
        'CMSSW_10_6_12',
        'CMSSW_10_6_2',
        'CMSSW_10_6_3',
        'CMSSW_10_6_4',
        'CMSSW_10_6_5',
        'CMSSW_10_6_6',
        'CMSSW_10_6_7',
        'CMSSW_10_6_8',
        'CMSSW_10_6_9',
        'CMSSW_11_0_0',
        'CMSSW_11_0_0_pre1',
        'CMSSW_11_0_0_pre10',
        'CMSSW_11_0_0_pre10_ROOT618',
        'CMSSW_11_0_0_pre11',
        'CMSSW_11_0_0_pre12',
        'CMSSW_11_0_0_pre13',
        'CMSSW_11_0_0_pre2',
        'CMSSW_11_0_0_pre3',
        'CMSSW_11_0_0_pre4',
        'CMSSW_11_0_0_pre5',
        'CMSSW_11_0_0_pre6',
        'CMSSW_11_0_0_pre7',
        'CMSSW_11_0_0_pre8',
        'CMSSW_11_0_0_pre9',
        'CMSSW_11_0_1',
        'CMSSW_11_0_2',
        'CMSSW_11_0_3',
        'CMSSW_11_1_0_pre1',
        'CMSSW_11_1_0_pre2',
        'CMSSW_11_1_0_pre2_Patatrack',
        'CMSSW_11_1_0_pre3',
        'CMSSW_11_1_0_pre4',
        'CMSSW_11_1_0_pre4_GEANT4',
        'CMSSW_11_1_0_pre4_GEANT4_NativeGeom',
        'CMSSW_11_1_0_pre4_Patatrack',
        'CMSSW_11_1_0_pre5',
        'CMSSW_11_1_0_pre5_Patatrack',
        'CMSSW_11_1_0_pre5_PY3',
        'CMSSW_11_1_0_pre6',
        'CMSSW_11_1_0_pre6_CLANG',
        ],
    'slc7_amd64_gcc900' : [
        'CMSSW_11_0_0_pre10',
        'CMSSW_11_0_0_pre11',
        'CMSSW_11_0_0_pre12',
        'CMSSW_11_0_0_pre13',
        'CMSSW_11_0_0_pre3',
        'CMSSW_11_0_0_pre4',
        'CMSSW_11_0_0_pre5',
        'CMSSW_11_0_0_pre6',
        'CMSSW_11_0_0_pre7',
        'CMSSW_11_0_0_pre8',
        'CMSSW_11_0_0_pre9',
        'CMSSW_11_1_0_pre1',
        'CMSSW_11_1_0_pre2',
        'CMSSW_11_1_0_pre3',
        'CMSSW_11_1_0_pre4',
        'CMSSW_11_1_0_pre5',
        'CMSSW_11_1_0_pre6',
        ],
    'slc7_ppc64le_gcc530' : [
        'CMSSW_8_1_0_pre13',
        'CMSSW_8_1_0_pre15',
        ],
    }

def get_arch(cmssw_version):
    # Passed string must contain a X_Y_Z-like version substring
    match = re.search(r'CMSSW_\d+_\d+_\d+', cmssw_version)
    if not match:
        raise RuntimeError('Invalid CMSSW version {0}'.format(cmssw_version))
    version_string = match.group()
    # Passed string may contain a suffix, X_Y_Z_suffix
    match = re.search(r'CMSSW_\d+_\d+_\d+_.*', cmssw_version)
    if match:
        version_string_with_suffix = match.group()
        cmssw_version = version_string_with_suffix
    else:
        version_string_with_suffix = None
        cmssw_version = version_string
    # Find all possible arches
    version_archs = set([])
    version_with_suffix_archs = set([])
    for arch, releases in RELEASES.items():
        for release in releases:
            if release.startswith(version_string):
                version_archs.update([arch])
            if version_string_with_suffix and release.startswith(version_string_with_suffix):
                version_with_suffix_archs.update([arch])
    # Convert to sorted lists
    version_archs = list(version_archs)
    version_archs.sort()
    version_with_suffix_archs = list(version_with_suffix_archs)
    version_with_suffix_archs.sort()
    # Return most likely candidate
    if version_with_suffix_archs:
        archs = version_with_suffix_archs
    elif version_archs:
        archs = version_archs
    else:
        raise RuntimeError(
            'Could not find a suitable arch for cmssw version {0}'
            .format(cmssw_version)
            )
    arch = archs[-1]
    if len(archs) > 1:
        logger.warning(
            'Found multiple candidate arches for cmssw_version %s; '
            'using arch %s (other candidates: %s)',
            cmssw_version, arch, archs
            )
    return arch
